@@ -177,7 +177,8 @@ class ClientApiError(Exception):
 
 class Client(object):
     def __init__(self, access_key=None, secret_key=None, url=None, cache=False,
-                 cache_time=86400, strict=False, **kw):
+                 cache_time=86400, strict=False, headers=HEADERS, **kw):
+        self._headers = headers
         self._access_key = access_key
         self._secret_key = secret_key
         self._auth = (self._access_key, self._secret_key)
@@ -254,7 +255,7 @@ class Client(object):
 
     def _get_response(self, url, data=None):
         r = self._session.get(url, auth=self._auth, params=data,
-                              headers=HEADERS)
+                              headers=self._headers)
         if r.status_code < 200 or r.status_code >= 300:
             self._error(r.text)
 
@@ -263,7 +264,7 @@ class Client(object):
     @timed_url
     def _post(self, url, data=None):
         r = self._session.post(url, auth=self._auth, data=self._marshall(data),
-                               headers=HEADERS)
+                               headers=self._headers)
         if r.status_code < 200 or r.status_code >= 300:
             self._error(r.text)
 
@@ -272,7 +273,7 @@ class Client(object):
     @timed_url
     def _put(self, url, data=None):
         r = self._session.put(url, auth=self._auth, data=self._marshall(data),
-                              headers=HEADERS)
+                              headers=self._headers)
         if r.status_code < 200 or r.status_code >= 300:
             self._error(r.text)
 
@@ -280,13 +281,15 @@ class Client(object):
 
     @timed_url
     def _delete(self, url):
-        r = self._session.delete(url, auth=self._auth, headers=HEADERS)
+        r = self._session.delete(url, auth=self._auth, headers=self._headers)
         if r.status_code < 200 or r.status_code >= 300:
             self._error(r.text)
 
         return self._unmarshall(r.text)
 
     def _unmarshall(self, text):
+        if text is None or text == '':
+            return text
         obj = json.loads(text, object_hook=self.object_hook,
                          object_pairs_hook=self.object_pairs_hook)
         return obj
